@@ -680,6 +680,8 @@ feh_draw_filename(winwidget w)
    int tw = 0, th = 0;
    Imlib_Image im = NULL;
    static DATA8 atab[256];
+   char *s = NULL;
+   int len = 0;
 
    D_ENTER(4);
 
@@ -706,21 +708,38 @@ feh_draw_filename(winwidget w)
    gib_imlib_get_text_size(fn, FEH_FILE(w->file->data)->filename, NULL, &tw, &th,
                            IMLIB_TEXT_TO_RIGHT);
 
+   /* tw is no longer correct, if the filename is shorter than
+    * the string "%d of %d" used below in fullscreen mode */
    tw += 3;
    th += 3;
-   im = imlib_create_image(tw, th);
+   im = imlib_create_image(tw, 2*th);
    if (!im)
       eprintf("Couldn't create image. Out of memory?");
 
    gib_imlib_image_set_has_alpha(im, 1);
-   gib_imlib_apply_color_modifier_to_rectangle(im, 0, 0, tw, th,
+   gib_imlib_apply_color_modifier_to_rectangle(im, 0, 0, tw, 2*th,
                                                NULL, NULL, NULL, atab);
-   gib_imlib_image_fill_rectangle(im, 0, 0, tw, th, 0, 0, 0, 0);
+   gib_imlib_image_fill_rectangle(im, 0, 0, tw, 2*th, 0, 0, 0, 0);
 
    gib_imlib_text_draw(im, fn, NULL, 2, 2, FEH_FILE(w->file->data)->filename,
                        IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
    gib_imlib_text_draw(im, fn, NULL, 1, 1, FEH_FILE(w->file->data)->filename,
                        IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
+   /* Print the position in the filelist, if we are in fullscreen and the
+    * list has more than one element */
+   if (w->full_screen && (gib_list_length(filelist)-1))
+   {
+      /* sic! */
+      len = snprintf(NULL, 0, "%d of %d", gib_list_length(filelist), gib_list_length(filelist))+1;
+      s = emalloc(len);
+      snprintf(s, len, "%d of %d",
+               gib_list_num(filelist, current_file) + 1,
+               gib_list_length(filelist));
+      /* This should somehow be right-aligned */
+      gib_imlib_text_draw(im, fn, NULL, 2, th+1, s, IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
+      gib_imlib_text_draw(im, fn, NULL, 1, th, s, IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
+      free(s);
+   }
 
    gib_imlib_render_image_on_drawable(w->bg_pmap, im, 0, 0, 1, 1, 0);
 
@@ -1176,3 +1195,98 @@ void feh_edit_inplace_lossless_rotate(winwidget w, int orientation) {
   free(outfilename);
 }
 
+void
+feh_draw_actions(winwidget w)
+{
+   static Imlib_Font fn = NULL;
+   int tw = 0, th = 0;
+   int max_tw = 0;
+   int line_th = 0;
+   Imlib_Image im = NULL;
+   static DATA8 atab[256];
+   int i = 0;
+   int num_actions = 0;
+   
+   D_ENTER(4);
+
+// count the number of defined actions
+   for (num_actions=0;opt.actions[num_actions];num_actions++)
+   	;
+   if (num_actions == 0)
+      return;
+   
+   if ((!w->file) || (!FEH_FILE(w->file->data))
+       || (!FEH_FILE(w->file->data)->filename))
+      D_RETURN_(4);
+
+   if (!fn)
+   {
+      memset(atab, 0, sizeof(atab));
+      if (w->full_screen)
+         fn = gib_imlib_load_font(DEFAULT_FONT_BIG);
+      else
+         fn = gib_imlib_load_font(DEFAULT_FONT);
+   }
+
+   if (!fn)
+   {
+      weprintf("Couldn't load font for actions printing");
+      D_RETURN_(4);
+   }
+
+
+   gib_imlib_get_text_size(fn, "defined actions:", NULL, &tw, &th,
+                           IMLIB_TEXT_TO_RIGHT);
+// Check for the widest line
+   max_tw = tw; 
+   for (i=0;opt.actions[i];i++) {
+   gib_imlib_get_text_size(fn, opt.actions[i], NULL, &tw, &th,
+                           IMLIB_TEXT_TO_RIGHT);
+   	if (tw>max_tw) {
+	   max_tw = tw;
+	}
+   }
+
+   tw = max_tw;
+   tw += 3;
+   th += 3;
+   line_th = th;
+   th = (th*num_actions)+line_th;
+
+   im = imlib_create_image(tw, th);
+   if (!im)
+      eprintf("Couldn't create image. Out of memory?");
+
+   gib_imlib_image_set_has_alpha(im, 1);
+   gib_imlib_apply_color_modifier_to_rectangle(im, 0, 0, tw, th,
+                                               NULL, NULL, NULL, atab);
+   gib_imlib_image_fill_rectangle(im, 0, 0, tw, th, 0, 0, 0, 0);
+   
+   gib_imlib_text_draw(im, fn, NULL, 1, 1, "defined actions:",
+                       IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
+   gib_imlib_text_draw(im, fn, NULL, 2, 2, "defined actions:",
+                       IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
+
+   for(i=0;i<num_actions;i++)
+   {
+//    compose a line containing an index, a colon followed by the
+//    action.
+      char index[1];
+      char line[strlen(opt.actions[i])+5];
+      sprintf(index, "%d", i);
+      strcpy(line, index);
+      strcat(line, ": ");
+      strcat(line, opt.actions[i]);
+
+      gib_imlib_text_draw(im, fn, NULL, 2, ((i+1)*line_th)+2, line,
+                          IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
+      gib_imlib_text_draw(im, fn, NULL, 1, ((i+1)*line_th)+1, line,
+                          IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
+      free(line);
+   }
+
+   gib_imlib_render_image_on_drawable(w->bg_pmap, im, 0, 0, 1, 1, 0);
+
+   gib_imlib_free_image_and_decache(im);
+   D_RETURN_(4);
+}
