@@ -302,10 +302,10 @@ feh_menu_find_selected_r(feh_menu * m, feh_menu **parent)
       D_RETURN(4, i);
     } else if (i->submenu) {
       mm = feh_menu_find(i->submenu);
-      if (mm)
+      if (mm) {
         ii = feh_menu_find_selected_r(mm, parent);
-      if (ii) {
-        D_RETURN(4, ii);
+      	if (ii)
+       		D_RETURN(4, ii);
       }
     }
   }
@@ -1053,8 +1053,6 @@ feh_menu_draw_toggle_at(int x,
                         int oy,
                         int on)
 {
-  int xc, yc;
-
   D_ENTER(5);
   x -= ox;
   y -= oy;
@@ -1251,7 +1249,6 @@ feh_menu_init_common()
   int num_desks, i;
   char buf[30];
   feh_menu *m;
-  feh_menu_item *mi;
 
   D_ENTER(4);
 
@@ -1722,7 +1719,7 @@ feh_menu_cb_reload(feh_menu * m,
                    void *data)
 {
   D_ENTER(4);
-  feh_reload_image(m->fehwin, 0);
+  feh_reload_image(m->fehwin, 0, 0);
   D_RETURN_(4);
   i = NULL;
   data = NULL;
@@ -1839,7 +1836,6 @@ feh_menu_cb_sort_randomize(feh_menu * m,
   data = NULL;
 }
 
-
 static feh_menu *
 feh_menu_func_gen_jump(feh_menu * m,
                        feh_menu_item * i,
@@ -1927,7 +1923,7 @@ feh_menu_func_gen_options(feh_menu * m,
                             opt.auto_zoom);
   feh_menu_add_toggle_entry(mm, "Freeze Window Size", NULL, NULL,
                             feh_menu_cb_opt_freeze_window, NULL, NULL,
-                            opt.geom);
+                            opt.geom_flags);
   feh_menu_add_toggle_entry(mm, "Fullscreen", NULL, NULL,
                             feh_menu_cb_opt_fullscreen, NULL, NULL,
                             m->fehwin->full_screen);
@@ -2050,11 +2046,12 @@ feh_menu_cb_opt_freeze_window(feh_menu * m,
 {
   MENU_ITEM_TOGGLE(i);
   if (MENU_ITEM_IS_ON(i)) {
-    opt.geom = TRUE;
+    opt.geom_flags = (WidthValue | HeightValue);
     opt.geom_w = m->fehwin->w;
     opt.geom_h = m->fehwin->h;
-  } else
-    opt.geom = FALSE;
+  } else {
+    opt.geom_flags = 0;
+  }
 }
 
 static void
