@@ -80,6 +80,8 @@ init_parse_options(int argc, char **argv)
    /* if we're using xinerama, then enable it by default */
    opt.xinerama = 1;
 #endif /* HAVE_LIBXINERAMA */
+
+   opt.fmmode = 0;
    
    D(3, ("About to parse env options (if any)\n"));
    /* Check for and parse any options in FEH_OPTIONS */
@@ -404,6 +406,10 @@ feh_parse_option_array(int argc, char **argv)
       {"action7", 1, 0, 216},
       {"action8", 1, 0, 217},
       {"action9", 1, 0, 218},
+      {"fmmode", 0, 0, 219},
+      {"draw-actions", 0, 0, 222},
+      {"cache-thumbnails", 0, 0, 223},
+      {"cycle-once", 0, 0, 224},
       {0, 0, 0, 0}
    };
    int optch = 0, cmdx = 0, i = 0;
@@ -719,6 +725,19 @@ feh_parse_option_array(int argc, char **argv)
         case 221:
            opt.hide_pointer = 1;
            break;
+        case 219:
+           opt.fmmode = 1; 
+           opt.sort = SORT_FILENAME;
+           break;
+        case 222:
+           opt.draw_actions = 1; 
+           break;
+        case 223:
+           opt.cache_thumbnails = 1;
+           break;
+        case 224:
+           opt.cycle_once = 1;
+           break;
         default:
            break;
       }
@@ -878,6 +897,7 @@ show_usage(void)
 " -D, --slideshow-delay NUM For slideshow mode, specifies time delay (seconds,\n"
 "                           can be a decimal) between automatically changing\n"
 "                           slides.\n"
+"     --cycle-once          exit feh after one loop through a slideshow\n"
 " -R, --reload NUM          Use this option to tell feh to reload an image\n"
 "                           after NUM seconds. Useful for viewing webcams\n"
 "                           via http, or even on your local machine.\n"
@@ -953,6 +973,7 @@ show_usage(void)
 "                           OPTIONS\n"
 " -t, --thumbnails          As --index, but clicking an image will open it in\n"
 "                           a new viewing window\n"
+"     --cache-thumbnails    Enable thumbnail caching\n"
 " -I, --fullindex           Same as index mode, but below each thumbnail you\n"
 "                           get image name, size and dimensions\n"
 "     --bg-tile FILE\n"
