@@ -67,6 +67,10 @@ struct __fehoptions
    unsigned char xinerama;
    unsigned char screen_clip;
    unsigned char hide_pointer;
+   unsigned char fmmode;
+   unsigned char draw_actions;
+   unsigned char cache_thumbnails;
+   unsigned char cycle_once;
 
    char *output_file;
    char *output_dir;
