@@ -27,10 +27,19 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "filelist.h"
 #include "options.h"
 #include "support.h"
-Window ipc_win = None, my_ipc_win = None;
+Window ipc_win = None;
+Window my_ipc_win = None;
 Atom ipc_atom = None;
 static unsigned char timeout = 0;
 
+/*
+ * This is a boolean indicating
+ * That while we seem to see E16 IPC
+ * it's actually E17 faking it
+ * -- richlowe 2005-06-22
+ */
+static char e17_fake_ipc = 0;
+
 void
 feh_wm_set_bg_file(char *file, unsigned char bgmode)
 {
@@ -217,15 +226,18 @@ feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
          fehbg = estrjoin(" ", "feh --bg-tile", fil, NULL);
       }
 
-      if(fehbg) {
+      if (fehbg) {
         home = getenv("HOME");
         if(home) {
           FILE *fp;
           char *path;
           path = estrjoin("/", home, ".fehbg", NULL);
-          fp = fopen(path, "w");
-          fprintf(fp, "%s\n", fehbg);
-          fclose(fp);
+          if ((fp = fopen(path, "w")) == NULL) {
+	     wprintf("Can't open %s for write", path);
+          } else {
+             fprintf(fp, "%s\n", fehbg);
+             fclose(fp);
+          }
           free(path);
         }
         free(fehbg);
@@ -302,7 +314,9 @@ feh_wm_get_wm_is_e(void)
    /* check if E is actually running */
    if (e == -1)
    {
-      if (XInternAtom(disp, "ENLIGHTENMENT_COMMS", True) != None)
+      /* XXX: This only covers E17 prior to 6/22/05 */
+      if ((XInternAtom(disp, "ENLIGHTENMENT_COMMS", True) != None) &&
+          (XInternAtom(disp, "ENLIGHTENMENT_VERSION", True) != None))
       {
          D(3, ("Enlightenment detected.\n"));
          e = 1;
@@ -328,6 +342,8 @@ feh_wm_get_num_desks(void)
       D_RETURN(4, -1);
 
    buf = enl_send_and_wait("num_desks ?");
+   if (buf == IPC_FAKE)         /* Fake E17 IPC */
+       D_RETURN(4, -1);
    D(3, ("Got from E IPC: %s\n", buf));
    ptr = buf;
    while (ptr && !isdigit(*ptr))
@@ -341,7 +357,7 @@ enl_ipc_get_win(void)
 {
 
    unsigned char *str = NULL;
-   Atom prop, prop2;
+   Atom prop, prop2, ever;
    unsigned long num, after;
    int format;
    Window dummy_win;
@@ -352,11 +368,26 @@ enl_ipc_get_win(void)
 
    D(3, ("Searching for IPC window.\n"));
 
+   /*
+    * Shortcircuit this entire func
+    * if we already know it's an e17 fake
+    */
+   if (e17_fake_ipc)
+     D_RETURN(4, ipc_win)
+   
    prop = XInternAtom(disp, "ENLIGHTENMENT_COMMS", True);
    if (prop == None)
    {
       D(3, ("Enlightenment is not running.\n"));
       D_RETURN(4, None);
+   } else {
+     /* XXX: This will only work with E17 prior to 6/22/2005 */
+     ever = XInternAtom(disp, "ENLIGHTENMENT_VERSION", True);
+     if (ever == None) {
+       /* This is an E without ENLIGHTENMENT_VERSION */
+       D(3, ("E16 IPC Protocol not supported"));
+       D_RETURN(4, None);
+     }
    }
    XGetWindowProperty(disp, root, prop, 0, 14, False, AnyPropertyType, &prop2,
                       &format, &num, &after, &str);
@@ -395,8 +426,26 @@ enl_ipc_get_win(void)
    }
    if (ipc_win != None)
    {
+
+      XGetWindowProperty(disp, ipc_win, ever, 0, 14, False, AnyPropertyType,
+                        &prop2, &format, &num, &after, &str);
+      if (str) {
+        /*
+         * This is E17's way of telling us it's only pretending
+         * as a workaround for a bug related to the way java handles
+         * Window Managers.
+         * (Only valid after date of this comment)
+         * -- richlowe 2005-06-22
+         */
+        XFree(str);
+        D(3,(" -> Found a fake E17 IPC window, ignoring"));
+        ipc_win = None;
+        e17_fake_ipc = 1;
+        D_RETURN(4, ipc_win);
+      }
+       
       D(3,
-        (" -> IPC Window found and verified as 0x%08x.  Registering Eterm as an IPC client.\n",
+        (" -> IPC Window found and verified as 0x%08x.  Registering feh as an IPC client.\n",
          (int) ipc_win));
       XSelectInput(disp, ipc_win,
                    StructureNotifyMask | SubstructureNotifyMask);
@@ -566,18 +615,28 @@ enl_ipc_get(const char *msg_data)
 char *
 enl_send_and_wait(char *msg)
 {
-
    char *reply = IPC_TIMEOUT;
    sighandler_t old_alrm;
 
    D_ENTER(4);
 
+   /*
+    * Shortcut this func and return IPC_FAKE
+    * If the IPC Window is the E17 fake
+    */
+   if (e17_fake_ipc)
+     return IPC_FAKE;
+   
    if (ipc_win == None)
    {
-      /* The IPC window is missing.  Wait for it to return or Eterm to be killed. */
+      /* The IPC window is missing.  Wait for it to return or feh to be killed. */
+      /* Only called once in the E17 case */
       for (; enl_ipc_get_win() == None;)
       {
-         sleep(1);
+         if (e17_fake_ipc)      
+           return IPC_FAKE;
+         else
+           sleep(1);
       }
    }
    old_alrm = (sighandler_t) signal(SIGALRM, (sighandler_t) enl_ipc_timeout);
