@@ -30,8 +30,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <X11/Intrinsic.h>                  /* Xlib, Xutil, Xresource, Xfuncproto */
 
 #define IPC_TIMEOUT    ((char *) 1)
+#define IPC_FAKE       ((char *) 2) /* Faked IPC */
 
-#define enl_ipc_sync()  do {{char *reply = enl_send_and_wait("nop"); free(reply);}} while (0)
+#define enl_ipc_sync()  do {                                           \
+       char *reply = enl_send_and_wait("nop");                         \
+       if ((reply != IPC_FAKE) && (reply != IPC_TIMEOUT))              \
+         free(reply);                                                  \
+   } while (0)                          
 
 extern Window ipc_win;
 extern Atom ipc_atom;
