@@ -181,6 +181,7 @@ init_thumbnail_mode(void)
 	 /* make sure we have an ~/.thumbnails/normal directory for storing
 			permanent thumbnails */
 	 td.cache_thumbnails = feh_thumbnail_setup_thumbnail_dir();
+   td.cache_thumbnails = opt.cache_thumbnails;
 
    for (l = filelist; l; l = l->next)
    {
@@ -784,23 +785,25 @@ feh_thumbnail_get_thumbnail(Imlib_Image *image, feh_file *file)
 	char *thumb_file = NULL, *uri = NULL;
 
 	if (!file || !file->filename)
-		D_RETURN(4, 0);
+		return(0);
 
 	if (td.cache_thumbnails)
 	{
 		uri = feh_thumbnail_get_name_uri(file->filename);
 		thumb_file = feh_thumbnail_get_name(uri);
 		status = feh_thumbnail_get_generated(image, file, thumb_file, uri);
+
 		if (!status)
 			status = feh_thumbnail_generate(image, file, thumb_file, uri);
 		
+    printf("uri is %s, thumb_file is %s\n", uri, thumb_file);
 		free(uri);
 		free(thumb_file);
 	}
 	else
 		status = feh_load_image(image, file);
 
-	D_RETURN(4, status);
+	return status;
 }
 
 char*
@@ -915,10 +918,10 @@ feh_thumbnail_generate(Imlib_Image *image, feh_file *file, char *thumb_file, cha
 
 		gib_imlib_free_image_and_decache(im_temp);
 
-		D_RETURN(4, 1);
+		return(1);
 	}
 
-	D_RETURN(4, 0);
+	return(0);
 }
 
 int
@@ -945,11 +948,11 @@ feh_thumbnail_get_generated(Imlib_Image *image, feh_file *file, char *thumb_file
 		{
       feh_load_image_char(image, thumb_file);
 
-			D_RETURN(4, 1);
+			return(1);
 		}
 	}
 
-	D_RETURN(4, 0);
+	return(0);
 }
 
 int
