@@ -15,13 +15,7 @@
 /* Although this file really shouldn't have access to the library internals,
  * it's helpful to let it call jround_up() and jcopy_block_row().
  */
-/*#define JPEG_INTERNALS*/
-
-/* Miscellaneous useful macros */
-#undef MAX
-#define MAX(a,b)	((a) > (b) ? (a) : (b))
-#undef MIN
-#define MIN(a,b)	((a) < (b) ? (a) : (b))
+#define JPEG_INTERNALS
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -38,7 +32,6 @@
     ((size_t) fwrite((const void *) (buf), (size_t) 1, (size_t) (sizeofbuf), (file)))
 
 
-#include "jerror.h"
 #include "jpeglib.h"
 #include "transupp.h"		/* My own external interface */
 
