@@ -546,6 +546,8 @@ winwidget_render_image(winwidget winwid,
 
   if (opt.draw_filename)
     feh_draw_filename(winwid);
+  if (opt.draw_actions)
+    feh_draw_actions(winwid);
   if ((opt.mode == MODE_ZOOM) && !alias)
     feh_draw_zoom(winwid);
   XSetWindowBackgroundPixmap(disp, winwid->win, winwid->bg_pmap);
@@ -565,6 +567,8 @@ void winwidget_render_image_cached(winwidget winwid) {
     feh_draw_caption(winwid);
   if (opt.draw_filename)
     feh_draw_filename(winwid);
+  if (opt.draw_actions)
+    feh_draw_actions(winwid);
   XSetWindowBackgroundPixmap(disp, winwid->win, winwid->bg_pmap);
   XClearWindow(disp, winwid->win);
 }
